@@ -2,6 +2,8 @@
 import matplotlib.image as mpimg
 import numpy as np
 import cv2
+import pygame
+
 
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
@@ -9,35 +11,7 @@ from scipy.spatial import ConvexHull
 # from scipy.spatial import Delaunay
 
 from voxelmap.annex import *
-
-
-def findcrossover(array,low,high,value):
-    'finds crossover index of array for `value` value'
-    if array[high] <= value:
-        return high
-    if array[low] > value:
-        return low 
-
-    middle = (high+low) // 2        # floor-division (indexes must be integers)
-
-    if array[middle] == value:
-        return middle
-    elif array[middle] < value:
-        findcrossover(array,middle+1,high,value)
-    
-    return findcrossover(array,low,middle-1,value)
-
-
-def findclosest(array, value): 
-    'adapted from: https://www.geeksforgeeks.org/python-find-closest-number-to-k-in-given-list/'      
-    idx = (np.abs(array - value)).argmin()
-    return idx
-
-def mat2crds(matrix):
-    # X,Y = matrix.shape
-    # Z = np.max(matrix,type=int)
-    crds  = [ [*i,matrix[tuple(i)]] for i in np.argwhere(matrix)]
-    return crds
+import voxelmap.objviewer as viewer
 
 class Image:
     def __init__(self,file):
@@ -52,6 +26,7 @@ class Image:
         '''
         self.file = file
         self.intensity = np.ones((5,5))
+        self.objfile = 'model.obj'
 
     def make(self, res = 1.0, res_interp = cv2.INTER_AREA):
         '''Turn image into intensity matrix i.e. matrix with pixel intensities
@@ -233,6 +208,7 @@ class Image:
         points2n=points2*5/np.max(points2)
         writeobj(points2n,hullsimplices2,out_file)
 
+        self.objfile = out_file 
 
         if plot:
             ax.set_title("{} Convex Hull segments".format(L_sectors**2),color="#D3D3D3")
@@ -240,4 +216,16 @@ class Image:
 
             set_axes_equal(ax)
             plt.axis('off')
-            plt.show()
\ No newline at end of file
+            plt.show()
+
+
+    # viewport_default = (0.8*np.array(pygame.display.set_mode().get_rect()[2:]))
+    def MeshView(self,viewport=(2048, 1152)):
+        '''MeshView: triangulated mesh view with OpenGL [ uses pygame ]
+
+        Parameters
+        ----------
+        viewport : (int,int)
+            viewport / screen (width, height) for display window (default: 80% your screen's width & height)
+        '''
+        viewer.objview(self.objfile, usemtl=False, viewport=viewport)
\ No newline at end of file
